@@ -47,10 +47,7 @@ pthread_exit(NULL);
 
 
 #include <fcntl.h> //we might check some files
-void start_test_instrument(ClutterActor *actor, ClutterEvent *event, gpointer data){
-
-    int type=GPOINTER_TO_INT(data);
-
+void start_test_instrument(int type){
     chum_test_instrument(type);
 
   ClutterActor* stage =main_getStage();
@@ -135,12 +132,9 @@ chum_slider_state(FALSE);
 }
 
 
-void start_slider(ClutterActor *actor, ClutterEvent *event, gpointer data){
-printf("Slider\n");
-  int type=GPOINTER_TO_INT(data);
+void start_test_slider(int type){
   chum_test_slider(type);
 
-
  ClutterActor* stage =main_getStage();
 
       ClutterActor* box=clutter_rectangle_new_with_color (get_blue_color());
