@@ -39,7 +39,7 @@ ClutterActor *choose_solo;
 
 extern ClutterActor* star_trace;
 extern JammoRecordingTrack* recording_track;
-extern char* selected_language;
+char* deprecated_selected_language;
 extern ClutterActor* mentor;
 extern ClutterActor *to_main_menu;
 
@@ -149,7 +149,7 @@ static ClutterActor* load_song_background_image(int i){
   ClutterActor* actor = clutter_texture_new ();
   gchar* filepath1;
 
-  filepath1 = g_strdup_printf("%s/background%s.png", chum_get_song_folder(i),selected_language );
+  filepath1 = g_strdup_printf("%s/background%s.png", chum_get_song_folder(i),deprecated_selected_language );
   //printf("filepath=%s\n",filepath1);
 
   int fd = open(filepath1,O_RDONLY);
@@ -183,7 +183,7 @@ static ClutterActor* load_song_image(int i){
   ClutterActor* actor = clutter_texture_new ();
   gchar* filepath1;
 
-  filepath1 = g_strdup_printf("%s/picture%s.png", chum_get_song_folder(i),selected_language);
+  filepath1 = g_strdup_printf("%s/picture%s.png", chum_get_song_folder(i),deprecated_selected_language);
   //printf("filepath=%s\n",filepath1);
 
   int fd = open(filepath1,O_RDONLY);
@@ -230,9 +230,9 @@ static void language_chosen(JammoTexture *actor, ClutterEvent *event, gpointer d
   clutter_actor_hide (choose_german);
   clutter_actor_hide (choose_english);
   switch (i) {
-    case 1:selected_language="";     break;
-    case 2:selected_language="_de";  break;
-    case 3:selected_language="_en";  break;
+    case 1:deprecated_selected_language="";     break;
+    case 2:deprecated_selected_language="_de";  break;
+    case 3:deprecated_selected_language="_en";  break;
   }
   init_song_table();
   clutter_actor_raise_top (group_of_songs);
@@ -455,7 +455,7 @@ void start_mobikid_recording(){
   
   //changing melodic contour cursor to correspond current song
   gchar* filepath1;
-  filepath1 = g_strdup_printf("%s/cursor%s.png", chum_get_song_folder(chum_get_current_song()),selected_language );
+  filepath1 = g_strdup_printf("%s/cursor%s.png", chum_get_song_folder(chum_get_current_song()),deprecated_selected_language );
   //printf("filepath=%s\n",filepath1);
 
   int fd = open(filepath1,O_RDONLY);
